from distutils.core import setup

setup(
    name            = "bd_nester",
    version         = "1.1.0",
    py_modules      = ["bd_nester"],
    author          = "darko bede",
    author_email    = "darko@bede.hr",
    url             = "http://www.bede.hr",
    description     = "A simple printer of nested lists",
    )
